# Changelog

### Other

- feat: moved to click; added fava-miler as console-script. [Red S]
- feat: Replace 9999-12-31 with the string no expiry. [Red S]
- chore: enable fava context and filters. Also upstream favaledger updates. [Red S]


## 0.2.3 (2022-04-03)


### Other

- Use new querytable, and bump up corresponding fava version required. [Red S]
- Bump beancount to 2.3.1 to use renamed get_commodity_directives. [Red S]
- Comments. [Red S]

## 0.2.2 (2020-10-12)


### Other

- Merge pull request #5 from redstreet/update. [Red S]

  beancount api get_commodity_map() -> get_commodity_directives()
- Beancount api get_commodity_map() -> get_commodity_directives() [AC]
- Fix #2: -1 to specify no expiration. [Red S]
- Add screenshot generating example. [Red S]
- Fix #1 (remove fava_investor from import) [Red S]

## 0.2.1 (2020-05-06)


### Other

- Fix publish. [Red S]

## 0.2.0 (2020-05-06)


### Other

- Create pythonpublish.yml. [Red S]
- Screenshot. [Red S]
- Add screenshot. [Red S]
- Dir move for pypi. [Red S]
- Update readme for fava, beancount. [Red S]
- README. [Red S]
- Value and expiry reports work. [Red S]
- Initial commit. [Red S]

